Skip to contents

Bibliographic database with JCR metrics (a wos.jcr S3 object) corresponding to a WoS search by the Affiliation field of Universidade da Coruña (UDC) in the research area "Mathematics" during the years 2018–2023 (generated fom wosdf data set, using the functions db_bib, db_jcr and add_jcr).

Usage

dbjcr

Format

An object of class wos.jcr (inherits from wos.db) of length 22.