Reads bibliography entries from UTF-8 encoded Tab-delimited files containing "Full Record and Cited References" (see wosdf and vignette Downloading data from the Web of Science).
Arguments
- path
character; path to the directory containing the files.
- pattern
regular expression; only matching files will be loaded. Defaults to
"*.txt".- all
logical; indicating whether sources without ISSN are included (
TRUE) or not (FALSE) in the result. Defaults toTRUE.- progress
logical; indicating whether a progress bar should be displayed. Defaults to
TRUEwhen R is used interactively and there is more than one file, andFALSEotherwise.