Retrieve internal identifiers (entity keys) for the corresponding relational
table (authors, sources, categories, areas, ...). Any field in the target
table can be used as a condition, and multiple conditions are combined with &
(only IDs for which all conditions evaluate to TRUE are returned).
Tidy evaluation can be used to construct the logical expressions,
see dplyr::filter().
Usage
get_id_docs(
db,
...,
id_sources,
id_authors,
id_addresses,
id_oi,
id_ri,
id_affiliations
)
get_id_authors(db, ...)
get_id_addresses(db, ...)
get_id_areas(db, ...)
get_id_categories(db, ...)
get_id_wsi(db, ...)
get_id_sources(db, ..., id_categories, id_areas, id_wsi)
get_id_oi(db, ...)
get_id_ri(db, ...)
get_id_affiliations(db, ...)Arguments
- db
- ...
Logical predicates. Multiple conditions are combined with
&(seefilter).- id_sources
optional; sources identifiers.
optional; author identifiers (values of
db$Authors$ids).- id_addresses
optional; addresses identifiers.
- id_oi
optional; ORCID identifiers or codes (values of
db$OI$OI).- id_ri
optional; RI identifiers or codes (values of
db$RI$RI).- id_affiliations
optional; affiliations identifiers or names (values of
db$Affiliations$C3).- id_categories
optional; categories identifiers or names (values of
db$Categories$WC)- id_areas
optional; research area identifiers or names (values of
db$Areas$SC)- id_wsi
optional; WoS Index identifiers or names (values of
db$WSI$WE)
Value
An integer vector of identifiers.
For instance, get_id_docs returns the document identifiers (values of
the db$Docs$idd variable) corresponding to identifiers of authors,
categories, areas, addresses and/or sources.
Logical expressions defined in terms of the variables in db$Docs can
also be used as arguments.